@@ -1,5 +1,5 @@
 #![forbid(unsafe_code)]
-#![forbid(missing_docs)]
+#![deny(missing_docs)]
 
 //! # Canary
 //! Canary is a library for making communication through the network easy.
@@ -19,6 +19,10 @@
 //! you should use [the book](https://znx3p0.github.io/canary-book/),
 //! and any questions should be asked in [the discord](https://discord.gg/QaWxMzAZs8)
 
+/// contains discovery structures
+pub mod discovery;
+/// offers the main types needed to use canary
+pub mod prelude;
 /// offers providers, which expose services through the network
 pub mod providers;
 /// offers the routing system used by services
@@ -36,3 +40,6 @@ pub use serde::{Deserialize, Serialize};
 pub use igcp::Result;
 pub use providers::Addr;
 pub use providers::ServiceAddr;
+
+#[cfg(not(target_arch = "wasm32"))]
+pub use routes::Ctx;
