@@ -1,45 +1,27 @@
-#[cfg(not(target_arch = "wasm32"))]
-use crate::routes::Status;
-
-#[cfg(target_arch = "wasm32")]
-#[derive(serde_repr::Serialize_repr, serde_repr::Deserialize_repr)]
-#[repr(u8)]
-/// used for discovery
-pub enum Status {
-    /// indicates a service has been found
-    Found = 1,
-    /// indicates a service has not been found
-    NotFound = 2,
-}
-
-#[cfg(not(target_arch = "wasm32"))]
-use crate::routes::GLOBAL_ROUTE;
-
-#[cfg(not(target_arch = "wasm32"))]
-use crate::runtime;
-#[cfg(not(target_arch = "wasm32"))]
-use crate::runtime::JoinHandle;
-
+use crate::discovery::Status;
 use crate::Result;
 
-#[cfg(not(target_arch = "wasm32"))]
-use async_tungstenite::tungstenite::protocol::Role;
-
+use cfg_if::cfg_if;
 use igcp::err;
-
-#[cfg(not(target_arch = "wasm32"))]
-use igcp::BareChannel;
-
 use igcp::Channel;
 
-#[cfg(not(target_arch = "wasm32"))]
-use async_std::net::{TcpListener, TcpStream, ToSocketAddrs};
+cfg_if! {
+    if #[cfg(not(target_arch = "wasm32"))] {
+        use crate::routes::GLOBAL_ROUTE;
+        use crate::runtime;
+        use crate::runtime::JoinHandle;
+        use async_tungstenite::tungstenite::protocol::Role;
+        use igcp::BareChannel;
+        use async_std::net::{TcpListener, TcpStream, ToSocketAddrs};
+    }
+}
 
 /// Exposes routes over WebSockets
 pub struct Wss(#[cfg(not(target_arch = "wasm32"))] TcpListener);
 
 #[cfg(not(target_arch = "wasm32"))]
 impl Wss {
+    #[inline]
     /// bind the global route on the given address
     pub async fn bind(addrs: impl ToSocketAddrs) -> Result<JoinHandle<Result<()>>> {
         let listener = TcpListener::bind(addrs).await?;
@@ -50,15 +32,15 @@ impl Wss {
                     let stream = async_tungstenite::accept_async(stream)
                         .await
                         .map_err(|e| err!(e.to_string()))?;
-                    // let stream = async_tungstenite::WebSocketStream::from_raw_socket(stream, Role::Server, None).await;
                     let chan: Channel = Channel::new_wss_encrypted(stream).await?;
                     let chan: BareChannel = chan.bare();
-                    GLOBAL_ROUTE.introduce_static_unspawn(chan).await?;
+                    GLOBAL_ROUTE.introduce(chan).await?;
                     Ok::<_, igcp::Error>(())
                 });
             }
         }))
     }
+    #[inline]
     /// connect to the following address without discovery
     pub async fn raw_connect_with_retries(
         addrs: impl ToSocketAddrs + std::fmt::Debug,
@@ -96,10 +78,12 @@ impl Wss {
         let chan = Channel::new_wss_encrypted(stream).await?;
         Ok(chan)
     }
+    #[inline]
     /// connect to the following address with the following id. Defaults to 3 retries.
     pub async fn connect(addrs: impl ToSocketAddrs + std::fmt::Debug, id: &str) -> Result<Channel> {
         Self::connect_retry(addrs, id, 3, 10).await
     }
+    #[inline]
     /// connect to the following address with the given id and retry in case of failure
     pub async fn connect_retry(
         addrs: impl ToSocketAddrs + std::fmt::Debug,
@@ -121,6 +105,7 @@ impl Wss {
 
 #[cfg(target_arch = "wasm32")]
 impl Wss {
+    #[inline]
     /// connect to the following address without discovery
     pub async fn raw_connect_with_retries(
         addrs: &str,
@@ -149,10 +134,12 @@ impl Wss {
         let chan = Channel::new_wss_encrypted(stream).await?;
         Ok(chan)
     }
+    #[inline]
     /// connect to the following address with the following id. Defaults to 3 retries.
     pub async fn connect(addrs: &str, id: &str) -> Result<Channel> {
         Self::connect_retry(addrs, id, 3, 10).await
     }
+    #[inline]
     /// connect to the following address with the given id and retry in case of failure
     pub async fn connect_retry(
         addrs: &str,
@@ -177,6 +164,7 @@ pub struct InsecureWss(#[cfg(not(target_arch = "wasm32"))] TcpListener);
 
 #[cfg(not(target_arch = "wasm32"))]
 impl InsecureWss {
+    #[inline]
     /// bind the global route on the given address
     pub async fn bind(addrs: impl ToSocketAddrs) -> Result<JoinHandle<Result<()>>> {
         let listener = TcpListener::bind(addrs).await?;
@@ -192,12 +180,13 @@ impl InsecureWss {
                     .await;
                     let chan: Channel = Channel::new_wss_encrypted(stream).await?;
                     let chan: BareChannel = chan.bare();
-                    GLOBAL_ROUTE.introduce_static_unspawn(chan).await?;
+                    GLOBAL_ROUTE.introduce(chan).await?;
                     Ok::<_, igcp::Error>(())
                 });
             }
         }))
     }
+    #[inline]
     /// connect to the following address without discovery
     pub async fn raw_connect_with_retries(
         addrs: impl ToSocketAddrs + std::fmt::Debug,
@@ -233,10 +222,12 @@ impl InsecureWss {
         let chan = Channel::new_wss_encrypted(stream).await?;
         Ok(chan)
     }
+    #[inline]
     /// connect to the following address with the following id. Defaults to 3 retries.
     pub async fn connect(addrs: impl ToSocketAddrs + std::fmt::Debug, id: &str) -> Result<Channel> {
         Self::connect_retry(addrs, id, 3, 10).await
     }
+    #[inline]
     /// connect to the following address with the given id and retry in case of failure
     pub async fn connect_retry(
         addrs: impl ToSocketAddrs + std::fmt::Debug,
@@ -258,6 +249,7 @@ impl InsecureWss {
 
 #[cfg(target_arch = "wasm32")]
 impl InsecureWss {
+    #[inline]
     /// connect to the following address without discovery
     pub async fn raw_connect_with_retries(
         addrs: &str,
@@ -286,10 +278,12 @@ impl InsecureWss {
         let chan = Channel::from(stream);
         Ok(chan)
     }
+    #[inline]
     /// connect to the following address with the following id. Defaults to 3 retries.
     pub async fn connect(addrs: &str, id: &str) -> Result<Channel> {
         Self::connect_retry(addrs, id, 3, 10).await
     }
+    #[inline]
     /// connect to the following address with the given id and retry in case of failure
     pub async fn connect_retry(
         addrs: &str,
